@@ -39,6 +39,14 @@ sub ACTION_nytprof {
 }
 
 
+sub ACTION_tags {
+    my ($self) = @_;
+
+    $self->depends_on('build');
+    $self->_run_tags();
+}
+
+
 sub authortest_dependencies {
     my ($self) = @_;
 
@@ -87,6 +95,31 @@ sub _run_nytprof {
 }
 
 
+sub _run_tags {
+    my ($self) = @_;
+
+    my $ctags = 'ctags';
+    my @ctags_args =
+        qw(
+            -f tags
+            --recurse
+            --totals
+            --exclude=blib
+            --exclude=.git
+            --exclude='*~'
+            --languages=Perl
+            --langmap=Perl:+.t
+        );
+    warn "Running: $ctags @ctags_args\n";
+
+    my $status_ctags = system $ctags, @ctags_args;
+    croak "ctags failed with status $status_ctags"
+        if $status_ctags == 1;
+
+    return;
+}
+
+
 1;
 
 
