@@ -9,7 +9,7 @@ use Perl::Critic::Utils qw{ :severities };
 use List::SomeUtils qw(any);
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.146';
+our $VERSION = '1.148';
 
 #-----------------------------------------------------------------------------
 
@@ -45,7 +45,7 @@ sub _uses_exporter {
     return if not $includes_ref;
 
     # This covers both C<use Exporter;> and C<use parent 'Exporter';>
-    return scalar grep { m/ \b Exporter \b/xms }  @{ $includes_ref };
+    return any { m/ \b Exporter \b/xms }  @{ $includes_ref };
 }
 
 #------------------
@@ -140,7 +140,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2021 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2023 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
